==> rest-assured-2.3.0-sources.jar: com/jayway/restassured/internal/filter/FormAuthFilter.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FormAuthFilter
  extends java.lang.Object  implements
    com.jayway.restassured.spi.AuthFilter,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getUserName() { return null;}
public  void setUserName(java.lang.Object value) { }
public  java.lang.Object getPassword() { return null;}
public  void setPassword(java.lang.Object value) { }
public  com.jayway.restassured.authentication.FormAuthConfig getFormAuthConfig() { return (com.jayway.restassured.authentication.FormAuthConfig)null;}
public  void setFormAuthConfig(com.jayway.restassured.authentication.FormAuthConfig value) { }
public  com.jayway.restassured.config.SessionConfig getSessionConfig() { return (com.jayway.restassured.config.SessionConfig)null;}
public  void setSessionConfig(com.jayway.restassured.config.SessionConfig value) { }
@java.lang.Override() public  com.jayway.restassured.response.Response filter(com.jayway.restassured.specification.FilterableRequestSpecification requestSpec, com.jayway.restassured.specification.FilterableResponseSpecification responseSpec, com.jayway.restassured.filter.FilterContext ctx) { return (com.jayway.restassured.response.Response)null;}
public  void applySessionFilterFromOriginalRequestIfDefined(com.jayway.restassured.specification.FilterableRequestSpecification requestSpec, com.jayway.restassured.specification.RequestSpecification loginRequestSpec) { }
public  java.lang.Object throwIfException(groovy.lang.Closure closure) { return null;}
}

==> rest-assured-2.3.3-sources.jar: com/jayway/restassured/internal/filter/FormAuthFilter.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FormAuthFilter
  extends java.lang.Object  implements
    com.jayway.restassured.spi.AuthFilter,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getUserName() { return null;}
public  void setUserName(java.lang.Object value) { }
public  java.lang.Object getPassword() { return null;}
public  void setPassword(java.lang.Object value) { }
public  com.jayway.restassured.authentication.FormAuthConfig getFormAuthConfig() { return (com.jayway.restassured.authentication.FormAuthConfig)null;}
public  void setFormAuthConfig(com.jayway.restassured.authentication.FormAuthConfig value) { }
public  com.jayway.restassured.config.SessionConfig getSessionConfig() { return (com.jayway.restassured.config.SessionConfig)null;}
public  void setSessionConfig(com.jayway.restassured.config.SessionConfig value) { }
@java.lang.Override() public  com.jayway.restassured.response.Response filter(com.jayway.restassured.specification.FilterableRequestSpecification requestSpec, com.jayway.restassured.specification.FilterableResponseSpecification responseSpec, com.jayway.restassured.filter.FilterContext ctx) { return (com.jayway.restassured.response.Response)null;}
public static  void applySessionFilterFromOriginalRequestIfDefined(com.jayway.restassured.specification.FilterableRequestSpecification requestSpec, com.jayway.restassured.specification.RequestSpecification loginRequestSpec) { }
public static  java.lang.Object throwIfException(groovy.lang.Closure closure) { return null;}
public static  java.lang.Object nullIfException(groovy.lang.Closure closure) { return null;}
}
